==> xs2a-impl-4.2-sources.jar: de/adorsys/psd2/xs2a/service/validator/pis/authorisation/initiation/UpdatePisCommonPaymentPsuDataPO.java <==
/*
 * Copyright 2018-2019 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.xs2a.service.validator.pis.authorisation.initiation;

import de.adorsys.psd2.consent.api.pis.proto.PisCommonPaymentResponse;
import de.adorsys.psd2.xs2a.core.profile.PaymentType;
import de.adorsys.psd2.xs2a.core.tpp.TppInfo;
import de.adorsys.psd2.xs2a.domain.consent.pis.Xs2aUpdatePisCommonPaymentPsuDataRequest;
import de.adorsys.psd2.xs2a.service.validator.pis.PaymentTypeAndInfoProvider;
import lombok.Value;
import org.jetbrains.annotations.NotNull;

/**
 * Payment object that contains necessary information for validating payment in {@link UpdatePisCommonPaymentPsuDataValidator}
 */
@Value
public class UpdatePisCommonPaymentPsuDataPO implements PaymentTypeAndInfoProvider {
    @NotNull
    private final PisCommonPaymentResponse pisCommonPaymentResponse;
    @NotNull
    private final Xs2aUpdatePisCommonPaymentPsuDataRequest updateRequest;

    @Override
    public TppInfo getTppInfo() {
        return pisCommonPaymentResponse.getTppInfo();
    }

    @Override
    public PaymentType getPaymentType() {
        return pisCommonPaymentResponse.getPaymentType();
    }

    @Override
    public String getPaymentProduct() {
        return pisCommonPaymentResponse.getPaymentProduct();
    }
}

==> xs2a-impl-8.6-sources.jar: de/adorsys/psd2/xs2a/service/validator/pis/authorisation/initiation/UpdatePisCommonPaymentPsuDataPO.java <==
/*
 * Copyright 2018-2019 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.xs2a.service.validator.pis.authorisation.initiation;

import de.adorsys.psd2.consent.api.pis.proto.PisCommonPaymentResponse;
import de.adorsys.psd2.xs2a.core.profile.PaymentType;
import de.adorsys.psd2.xs2a.core.tpp.TppInfo;
import de.adorsys.psd2.xs2a.domain.consent.pis.Xs2aUpdatePisCommonPaymentPsuDataRequest;
import de.adorsys.psd2.xs2a.service.validator.pis.authorisation.UpdatePisPsuDataPO;
import lombok.Value;
import org.jetbrains.annotations.NotNull;

/**
 * Payment object that contains necessary information for validating payment in {@link UpdatePisCommonPaymentPsuDataValidator}
 */
@Value
public class UpdatePisCommonPaymentPsuDataPO implements UpdatePisPsuDataPO {
    @NotNull
    private final PisCommonPaymentResponse pisCommonPaymentResponse;
    @NotNull
    private final Xs2aUpdatePisCommonPaymentPsuDataRequest updateRequest;

    @Override
    public TppInfo getTppInfo() {
        return pisCommonPaymentResponse.getTppInfo();
    }

    @Override
    public PaymentType getPaymentType() {
        return updateRequest.getPaymentService();
    }

    @Override
    public String getPaymentProduct() {
        return updateRequest.getPaymentProduct();
    }
}
